@@ -89,129 +89,6 @@ pk_strv_to_ptr_array (gchar **array)
 	return parray;
 }
 
-/**
- * _gtk_text_buffer_insert_markup:
- * @buffer: a #GtkTextBuffer
- * @markup: nul-terminated UTF-8 text with pango markup to insert
- **/
-void
-_gtk_text_buffer_insert_markup (GtkTextBuffer *buffer, GtkTextIter *iter, const gchar *markup)
-{
-	PangoAttrIterator *paiter;
-	PangoAttrList *attrlist;
-	GtkTextMark *mark;
-	GError *error = NULL;
-	gchar *text;
-
-	g_return_if_fail (GTK_IS_TEXT_BUFFER (buffer));
-	g_return_if_fail (markup != NULL);
-
-	if (*markup == '\000')
-		return;
-
-	/* invalid */
-	if (!pango_parse_markup (markup, -1, 0, &attrlist, &text, NULL, &error)) {
-		g_warning ("Invalid markup string: %s", error->message);
-		g_error_free (error);
-		return;
-	}
-
-	/* trivial, no markup */
-	if (attrlist == NULL) {
-		gtk_text_buffer_insert (buffer, iter, text, -1);
-		g_free (text);
-		return;
-	}
-
-	/* create mark with right gravity */
-	mark = gtk_text_buffer_create_mark (buffer, NULL, iter, FALSE);
-	paiter = pango_attr_list_get_iterator (attrlist);
-
-	do {
-		PangoAttribute *attr;
-		GtkTextTag *tag;
-		GtkTextTag *tag_para;
-		gint start, end;
-
-		pango_attr_iterator_range (paiter, &start, &end);
-
-		if (end == G_MAXINT)	/* last chunk */
-			end = start-1; /* resulting in -1 to be passed to _insert */
-
-		tag = gtk_text_tag_new (NULL);
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_LANGUAGE)))
-			g_object_set (tag, "language", pango_language_to_string ( ( (PangoAttrLanguage*)attr)->value), NULL);
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_FAMILY)))
-			g_object_set (tag, "family", ( (PangoAttrString*)attr)->value, NULL);
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_STYLE)))
-			g_object_set (tag, "style", ( (PangoAttrInt*)attr)->value, NULL);
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_WEIGHT)))
-			g_object_set (tag, "weight", ( (PangoAttrInt*)attr)->value, NULL);
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_VARIANT)))
-			g_object_set (tag, "variant", ( (PangoAttrInt*)attr)->value, NULL);
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_STRETCH)))
-			g_object_set (tag, "stretch", ( (PangoAttrInt*)attr)->value, NULL);
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_SIZE)))
-			g_object_set (tag, "size", ( (PangoAttrInt*)attr)->value, NULL);
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_FONT_DESC)))
-			g_object_set (tag, "font-desc", ( (PangoAttrFontDesc*)attr)->desc, NULL);
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_FOREGROUND))) {
-			GdkColor col = { 0,
-					( (PangoAttrColor*)attr)->color.red,
-					( (PangoAttrColor*)attr)->color.green,
-					( (PangoAttrColor*)attr)->color.blue
-					};
-
-			g_object_set (tag, "foreground-gdk", &col, NULL);
-		}
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_BACKGROUND))) {
-			GdkColor col = { 0,
-					( (PangoAttrColor*)attr)->color.red,
-					( (PangoAttrColor*)attr)->color.green,
-					( (PangoAttrColor*)attr)->color.blue
-					};
-
-			g_object_set (tag, "background-gdk", &col, NULL);
-		}
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_UNDERLINE)))
-			g_object_set (tag, "underline", ( (PangoAttrInt*)attr)->value, NULL);
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_STRIKETHROUGH)))
-			g_object_set (tag, "strikethrough", (gboolean) ( ( (PangoAttrInt*)attr)->value != 0), NULL);
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_RISE)))
-			g_object_set (tag, "rise", ( (PangoAttrInt*)attr)->value, NULL);
-
-		if ( (attr = pango_attr_iterator_get (paiter, PANGO_ATTR_SCALE)))
-			g_object_set (tag, "scale", ( (PangoAttrFloat*)attr)->value, NULL);
-
-		gtk_text_tag_table_add (gtk_text_buffer_get_tag_table (buffer), tag);
-
-		tag_para = gtk_text_tag_table_lookup (gtk_text_buffer_get_tag_table (buffer), "para");
-		gtk_text_buffer_insert_with_tags (buffer, iter, text+start, end - start, tag, tag_para, NULL);
-
-		/* mark had right gravity, so it should be
-		 *	at the end of the inserted text now */
-		gtk_text_buffer_get_iter_at_mark (buffer, iter, mark);
-	} while (pango_attr_iterator_next (paiter));
-
-	gtk_text_buffer_delete_mark (buffer, mark);
-	pango_attr_iterator_destroy (paiter);
-	pango_attr_list_unref (attrlist);
-	g_free (text);
-}
-
 /**
  * gpk_window_set_size_request:
  **/
